from setuptools import setup, find_packages

setup(
    name='Stsocialicon',
    version='0.0.3',
    packages=find_packages(),
    author='Sumit Kumar Singh',
    author_email='sumitsingh9441@gmail.com',
    description='A package for generating social media icons with customizable colors and sizes.',
    keywords = "streamlit social media links",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/RAJPUTRoCkStAr/Stsocialicon',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
